# pyIEX

# Attribution
## If you redistribute our API data:

- Cite IEX using the following text and link: “Data provided for free by IEX.”
- Provide a link to https://iextrading.com/api-exhibit-a in your terms of service.
- Additionally, if you display our TOPS price data, cite “IEX Real-Time Price” near the price.
